Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(667)

Unified Diff: content/child/browser_font_resource_trusted.h

Issue 2717943002: Fix cc/paint skia type mismatches (Closed)
Patch Set: Rebase Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/child/browser_font_resource_trusted.h
diff --git a/content/child/browser_font_resource_trusted.h b/content/child/browser_font_resource_trusted.h
index 2e399badca7964832db8c9ff7f8b879a3363d91f..aef873d80e538b14538cf1aaa1904751d4fe955b 100644
--- a/content/child/browser_font_resource_trusted.h
+++ b/content/child/browser_font_resource_trusted.h
@@ -9,6 +9,7 @@
#include <string>
#include "base/macros.h"
+#include "cc/paint/paint_canvas.h"
#include "ppapi/c/pp_bool.h"
#include "ppapi/c/pp_instance.h"
#include "ppapi/c/pp_resource.h"
@@ -17,8 +18,6 @@
#include "ppapi/shared_impl/ppapi_preferences.h"
#include "ppapi/thunk/ppb_browser_font_trusted_api.h"
-class SkCanvas;
-
namespace blink {
class WebFont;
}
@@ -60,8 +59,8 @@ class BrowserFontResource_Trusted
private:
~BrowserFontResource_Trusted() override;
- // Internal version of DrawTextAt that takes a mapped PlatformCanvas.
- void DrawTextToCanvas(SkCanvas* destination,
+ // Internal version of DrawTextAt that takes a mapped PaintCanvas.
+ void DrawTextToCanvas(cc::PaintCanvas* destination,
const PP_BrowserFont_Trusted_TextRun& text,
const PP_Point* position,
uint32_t color,
« no previous file with comments | « content/child/BUILD.gn ('k') | content/renderer/media/capturefromelement/html_video_element_capturer_source_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698